@@ -106,7 +106,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 1 "./styleparser.yy"
+#line 1 "../../../lib/srchilite/styleparser.yy"
 
 /*
  * Copyright (C) 1999-2007 Lorenzo Bettini <http://www.lorenzobettini.it>
@@ -188,7 +188,7 @@ static string errorBuffer;
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 62 "./styleparser.yy"
+#line 62 "../../../lib/srchilite/styleparser.yy"
 {
   int tok ; /* command */
   const std::string * string ; /* string : id, ... */
@@ -1117,7 +1117,7 @@ yydestruct (yymsg, yytype, yyvaluep)
   switch (yytype)
     {
       case 9: /* "KEY" */
-#line 79 "./styleparser.yy"
+#line 79 "../../../lib/srchilite/styleparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
@@ -1125,7 +1125,7 @@ yydestruct (yymsg, yytype, yyvaluep)
 #line 1126 "styleparser.cc"
 	break;
       case 10: /* "COLOR" */
-#line 79 "./styleparser.yy"
+#line 79 "../../../lib/srchilite/styleparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
@@ -1133,7 +1133,7 @@ yydestruct (yymsg, yytype, yyvaluep)
 #line 1134 "styleparser.cc"
 	break;
       case 11: /* "BG_COLOR" */
-#line 79 "./styleparser.yy"
+#line 79 "../../../lib/srchilite/styleparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
@@ -1141,7 +1141,7 @@ yydestruct (yymsg, yytype, yyvaluep)
 #line 1142 "styleparser.cc"
 	break;
       case 12: /* "STRINGDEF" */
-#line 79 "./styleparser.yy"
+#line 79 "../../../lib/srchilite/styleparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
@@ -1149,7 +1149,7 @@ yydestruct (yymsg, yytype, yyvaluep)
 #line 1150 "styleparser.cc"
 	break;
       case 24: /* "keylist" */
-#line 79 "./styleparser.yy"
+#line 79 "../../../lib/srchilite/styleparser.yy"
 	{
 	if ((yyvaluep->keylist))
 	  delete (yyvaluep->keylist);
@@ -1157,7 +1157,7 @@ yydestruct (yymsg, yytype, yyvaluep)
 #line 1158 "styleparser.cc"
 	break;
       case 25: /* "color" */
-#line 79 "./styleparser.yy"
+#line 79 "../../../lib/srchilite/styleparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
@@ -1165,7 +1165,7 @@ yydestruct (yymsg, yytype, yyvaluep)
 #line 1166 "styleparser.cc"
 	break;
       case 26: /* "bgcolor" */
-#line 79 "./styleparser.yy"
+#line 79 "../../../lib/srchilite/styleparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
@@ -1479,12 +1479,12 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 86 "./styleparser.yy"
+#line 86 "../../../lib/srchilite/styleparser.yy"
     { /* allow empty files */ }
     break;
 
   case 8:
-#line 99 "./styleparser.yy"
+#line 99 "../../../lib/srchilite/styleparser.yy"
     {
                  //printSequence( $1 ) ;
                  //printMessage_noln( ": " ) ;
@@ -1495,7 +1495,7 @@ yyreduce:
     break;
 
   case 9:
-#line 107 "./styleparser.yy"
+#line 107 "../../../lib/srchilite/styleparser.yy"
     {
                KeyType key;
                KeyList *keylist = (yyvsp[(1) - (6)].keylist);
@@ -1524,7 +1524,7 @@ yyreduce:
     break;
 
   case 10:
-#line 135 "./styleparser.yy"
+#line 135 "../../../lib/srchilite/styleparser.yy"
     {
               (yyvsp[(1) - (3)].keylist)->push_back(*(yyvsp[(3) - (3)].string));
               (yyval.keylist) = (yyvsp[(1) - (3)].keylist);
@@ -1533,7 +1533,7 @@ yyreduce:
     break;
 
   case 11:
-#line 141 "./styleparser.yy"
+#line 141 "../../../lib/srchilite/styleparser.yy"
     {
               (yyval.keylist) = new KeyList;
               (yyval.keylist)->push_back(*(yyvsp[(1) - (1)].string));
@@ -1542,92 +1542,92 @@ yyreduce:
     break;
 
   case 12:
-#line 148 "./styleparser.yy"
+#line 148 "../../../lib/srchilite/styleparser.yy"
     { (yyval.string) = 0; }
     break;
 
   case 13:
-#line 149 "./styleparser.yy"
+#line 149 "../../../lib/srchilite/styleparser.yy"
     { (yyval.string) = (yyvsp[(1) - (1)].string);}
     break;
 
   case 14:
-#line 150 "./styleparser.yy"
+#line 150 "../../../lib/srchilite/styleparser.yy"
     { (yyval.string) = (yyvsp[(1) - (1)].string); }
     break;
 
   case 15:
-#line 153 "./styleparser.yy"
+#line 153 "../../../lib/srchilite/styleparser.yy"
     { (yyval.string) = 0; }
     break;
 
   case 16:
-#line 154 "./styleparser.yy"
+#line 154 "../../../lib/srchilite/styleparser.yy"
     { (yyval.string) = (yyvsp[(3) - (3)].string);}
     break;
 
   case 17:
-#line 155 "./styleparser.yy"
+#line 155 "../../../lib/srchilite/styleparser.yy"
     { (yyval.string) = (yyvsp[(3) - (3)].string); }
     break;
 
   case 18:
-#line 158 "./styleparser.yy"
+#line 158 "../../../lib/srchilite/styleparser.yy"
     { updateBgColor((yyvsp[(2) - (3)].string)); }
     break;
 
   case 19:
-#line 159 "./styleparser.yy"
+#line 159 "../../../lib/srchilite/styleparser.yy"
     { updateBgColor((yyvsp[(2) - (3)].string)); }
     break;
 
   case 20:
-#line 162 "./styleparser.yy"
+#line 162 "../../../lib/srchilite/styleparser.yy"
     { (yyval.styleconstants) = 0 ; }
     break;
 
   case 21:
-#line 163 "./styleparser.yy"
+#line 163 "../../../lib/srchilite/styleparser.yy"
     { (yyval.styleconstants) = (yyvsp[(1) - (1)].styleconstants); }
     break;
 
   case 22:
-#line 166 "./styleparser.yy"
+#line 166 "../../../lib/srchilite/styleparser.yy"
     { (yyval.styleconstants) = (yyvsp[(1) - (3)].styleconstants); (yyval.styleconstants)->push_back((yyvsp[(3) - (3)].flag)) ; }
     break;
 
   case 23:
-#line 167 "./styleparser.yy"
+#line 167 "../../../lib/srchilite/styleparser.yy"
     { (yyval.styleconstants) = new StyleConstants; (yyval.styleconstants)->push_back((yyvsp[(1) - (1)].flag)); }
     break;
 
   case 24:
-#line 170 "./styleparser.yy"
+#line 170 "../../../lib/srchilite/styleparser.yy"
     { (yyval.flag) = ISBOLD ; }
     break;
 
   case 25:
-#line 171 "./styleparser.yy"
+#line 171 "../../../lib/srchilite/styleparser.yy"
     { (yyval.flag) = ISITALIC ; }
     break;
 
   case 26:
-#line 172 "./styleparser.yy"
+#line 172 "../../../lib/srchilite/styleparser.yy"
     { (yyval.flag) = ISUNDERLINE ; }
     break;
 
   case 27:
-#line 173 "./styleparser.yy"
+#line 173 "../../../lib/srchilite/styleparser.yy"
     { (yyval.flag) = ISFIXED ; }
     break;
 
   case 28:
-#line 174 "./styleparser.yy"
+#line 174 "../../../lib/srchilite/styleparser.yy"
     { (yyval.flag) = ISNOTFIXED ; }
     break;
 
   case 29:
-#line 175 "./styleparser.yy"
+#line 175 "../../../lib/srchilite/styleparser.yy"
     { (yyval.flag) = ISNOREF ; }
     break;
 
@@ -1847,7 +1847,7 @@ yyreturn:
 }
 
 
-#line 178 "./styleparser.yy"
+#line 178 "../../../lib/srchilite/styleparser.yy"
 
 
 string current_file;
